**Agenda**

* ~"priority :1" review
* ~review review
* Sprint review
  * Topic 1
* Next Milestone review
  * Topic 1
* Set priorities for new issues
* Set scope and set ~backlog for issues in next sprint

------------------------------

**Meeting Notes**
